@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "ApplyExternalSettings.hpp"
 #include "Interface.hpp"
@@ -182,6 +162,24 @@ RadioProcess() noexcept
   return modified;
 }
 
+static bool
+TransponderProcess() noexcept
+{
+  bool modified = false;
+
+  const NMEAInfo &basic = CommonInterface::Basic();
+
+  static Validity last_transponder_code;
+
+  if (basic.settings.has_transponder_code.Modified(last_transponder_code)) {
+    ActionInterface::SetTransponderCode(basic.settings.transponder_code, false);
+    last_transponder_code = basic.settings.has_transponder_code;
+    modified = true;
+  }
+
+  return modified;
+}
+
 bool
 ApplyExternalSettings(OperationEnvironment &env) noexcept
 {
@@ -192,5 +190,6 @@ ApplyExternalSettings(OperationEnvironment &env) noexcept
   modified |= QNHProcessTimer(env);
   modified |= MacCreadyProcessTimer();
   modified |= RadioProcess();
+  modified |= TransponderProcess();
   return modified;
 }
