@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "Device/Driver/Eye.hpp"
 #include "Device/Driver.hpp"
@@ -30,6 +10,8 @@ Copyright_License {
 #include "Atmosphere/Pressure.hpp"
 #include "Math/Util.hpp"
 
+using std::string_view_literals::operator""sv;
+
 class EyeDevice : public AbstractDevice {
 public:
   /* virtual methods from class Device */
@@ -50,12 +32,11 @@ EyeDevice::ParseNMEA(const char *_line, NMEAInfo &info)
     return false;
 
   NMEAInputLine line(_line);
-  char type[16];
-  line.Read(type, 16);
 
-  if (StringIsEqual(type, "$PEYA"))
+  const auto type = line.ReadView();
+  if (type == "$PEYA"sv)
     return PEYA(line, info);
-  else if (StringIsEqual(type, "$PEYI"))
+  else if (type == "$PEYI"sv)
     return PEYI(line, info);
   else
     return false;
