@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "Device.hpp"
 #include "Device/Parser.hpp"
@@ -28,6 +8,8 @@ Copyright_License {
 #include "NMEA/Checksum.hpp"
 #include "Units/System.hpp"
 
+using std::string_view_literals::operator""sv;
+
 /**
  * Parse a "$BRSF" sentence.
  *
@@ -250,14 +232,13 @@ FlytecDevice::ParseNMEA(const char *_line, NMEAInfo &info)
     return false;
 
   NMEAInputLine line(_line);
-  char type[16];
-  line.Read(type, 16);
 
-  if (StringIsEqual(type, "$BRSF"))
+  const auto type = line.ReadView();
+  if (type == "$BRSF"sv)
     return FlytecParseBRSF(line, info);
-  else if (StringIsEqual(type, "$VMVABD"))
+  else if (type == "$VMVABD"sv)
     return FlytecParseVMVABD(line, info);
-  else if (StringIsEqual(type, "$FLYSEN"))
+  else if (type == "$FLYSEN"sv)
     return ParseFLYSEN(line, info);
   else
     return false;
