@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2022 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "Internal.hpp"
 #include "NanoDeclare.hpp"
@@ -180,16 +160,16 @@ DeclareInner(Port &port, const Declaration &declaration,
   LX::SendCommand(port, LX::WRITE_FLIGHT_INFO); // start declaration
 
   LX::CRCWriter writer(port);
-  writer.Write(&pilot, sizeof(pilot), env);
+  writer.Write(std::as_bytes(std::span{&pilot, 1}), env);
   env.SetProgressPosition(3);
 
-  writer.Write(&lx_driver_Declaration, sizeof(lx_driver_Declaration), env);
+  writer.Write(std::as_bytes(std::span{&lx_driver_Declaration, 1}), env);
   writer.Flush();
   LX::ExpectACK(port, env);
 
   env.SetProgressPosition(4);
   LX::SendCommand(port, LX::WRITE_CONTEST_CLASS);
-  writer.Write(&contest_class, sizeof(contest_class), env);
+  writer.Write(std::as_bytes(std::span{&contest_class, 1}), env);
   env.SetProgressPosition(5);
 
   writer.Flush();
