@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2022 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "Device/Driver/Vaulter.hpp"
 #include "Device/Driver.hpp"
@@ -28,6 +8,8 @@ Copyright_License {
 #include "NMEA/InputLine.hpp"
 #include "NMEA/Checksum.hpp"
 
+using std::string_view_literals::operator""sv;
+
 static bool
 ParsePITV3(NMEAInputLine &line, NMEAInfo &info)
 {
@@ -162,14 +144,13 @@ VaulterDevice::ParseNMEA(const char *_line, NMEAInfo &info)
     return false;
 
   NMEAInputLine line(_line);
-  char type[16];
-  line.Read(type, 16);
 
-  if (StringIsEqual(type, "$PITV3"))
+  const auto type = line.ReadView();
+  if (type == "$PITV3"sv)
     return ParsePITV3(line, info);
-  else if (StringIsEqual(type, "$PITV4"))
+  else if (type == "$PITV4"sv)
     return ParsePITV4(line, info);
-  else if (StringIsEqual(type, "$PITV5"))
+  else if (type == "$PITV5"sv)
     return ParsePITV5(line, info);
   else
     return false;
