@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "Protocol.hpp"
 #include "util/CRC.hpp"
@@ -99,12 +79,12 @@ Volkslogger::ConnectAndFlush(Port &port, OperationEnvironment &env,
 }
 
 static void
-SendWithCRC(Port &port, const void *data, size_t length,
+SendWithCRC(Port &port, std::span<const std::byte> src,
             OperationEnvironment &env)
 {
-  port.FullWrite(data, length, env, std::chrono::seconds(2));
+  port.FullWrite(src, env, std::chrono::seconds(2));
 
-  uint16_t crc16 = UpdateCRC16CCITT(data, length, 0);
+  uint16_t crc16 = UpdateCRC16CCITT(src.data(), src.size(), 0);
   port.Write(crc16 >> 8);
   port.Write(crc16 & 0xff);
 }
@@ -133,7 +113,7 @@ Volkslogger::SendCommand(Port &port, OperationEnvironment &env,
 
   env.Sleep(delay);
 
-  SendWithCRC(port, cmdarray, sizeof(cmdarray), env);
+  SendWithCRC(port, std::as_bytes(std::span{cmdarray}), env);
 
   /* wait for confirmation */
 
@@ -311,7 +291,7 @@ Volkslogger::WriteBulk(Port &port, OperationEnvironment &env,
     if (n > 400)
       n = 400;
 
-    n = port.Write(p, n);
+    n = port.Write(std::as_bytes(std::span{p, n}));
 
     crc16 = UpdateCRC16CCITT(p, n, crc16);
     p += n;
