@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2022 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "Device/Driver/XCOM760.hpp"
 #include "Device/Driver.hpp"
@@ -50,7 +30,7 @@ XCOM760Device::PutVolume(unsigned volume, OperationEnvironment &env)
 {
   char szTmp[32];
   sprintf(szTmp, "$RVOL=%u\r\n", volume);
-  port.FullWriteString(szTmp, env, std::chrono::milliseconds{100});
+  port.FullWrite(szTmp, env, std::chrono::milliseconds{100});
   return true;
 }
 
@@ -63,7 +43,7 @@ XCOM760Device::PutActiveFrequency(RadioFrequency frequency,
   sprintf(szTmp, "$TXAF=%u.%03u\r\n",
           frequency.GetKiloHertz() / 1000,
           frequency.GetKiloHertz() % 1000);
-  port.FullWriteString(szTmp, env, std::chrono::milliseconds{100});
+  port.FullWrite(szTmp, env, std::chrono::milliseconds{100});
   return true;
 }
 
@@ -76,7 +56,7 @@ XCOM760Device::PutStandbyFrequency(RadioFrequency frequency,
   sprintf(szTmp, "$TXSF=%u.%03u\r\n",
           frequency.GetKiloHertz() / 1000,
           frequency.GetKiloHertz() % 1000);
-  port.FullWriteString(szTmp, env, std::chrono::milliseconds{100});
+  port.FullWrite(szTmp, env, std::chrono::milliseconds{100});
   return true;
 }
 
