@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2022 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "TTYPort.hpp"
 #include "Device/Error.hpp"
@@ -266,7 +246,7 @@ TTYPort::WaitWrite(unsigned timeout_ms)
 }
 
 std::size_t
-TTYPort::Write(const void *data, std::size_t length)
+TTYPort::Write(std::span<const std::byte> src)
 {
   assert(socket.IsDefined());
 
@@ -274,14 +254,14 @@ TTYPort::Write(const void *data, std::size_t length)
     throw std::runtime_error("Port is closed");
 
   TTYDescriptor fd(socket.GetFileDescriptor());
-  auto nbytes = fd.Write(data, length);
+  auto nbytes = fd.Write(src.data(), src.size());
   if (nbytes < 0) {
     if (errno != EAGAIN)
       /* the output fifo is full; wait until we can write (or until
          the timeout expires) */
       WaitWrite(5000);
 
-    nbytes = fd.Write(data, length);
+    nbytes = fd.Write(src.data(), src.size());
     if (nbytes < 0)
       throw MakeErrno("Port write failed");
   }
