@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2022 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #pragma once
 
@@ -53,7 +33,9 @@ class DeviceSettingsMap {
 
     bool old;
 
-    explicit constexpr Item(const V &_value) noexcept:value(_value) {}
+    template<typename VV>
+    explicit constexpr Item(VV &&_value) noexcept
+      :value(std::forward<VV>(_value)) {}
   };
 
   using Map = std::map<std::string, Item, std::less<>>;
@@ -133,9 +115,10 @@ public:
     return const_iterator(map.end());
   }
 
-  template<typename K>
-  void Set(const K &key, const V &value) {
-    auto [it, _] = map.insert_or_assign(key, Item(value));
+  template<typename K, typename VV>
+  void Set(K &&key, VV &&value) {
+    auto [it, _] = map.insert_or_assign(std::forward<K>(key),
+                                        Item{std::forward<VV>(value)});
     Item &item = it->second;
     item.old = false;
 
