@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2022 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "DeviceListDialog.hpp"
 #include "DeviceEditWidget.hpp"
@@ -81,7 +61,8 @@ class DeviceListWidget final
     bool alive:1, location:1, gps:1, baro:1, pitot:1, airspeed:1, vario:1, traffic:1;
     bool temperature:1;
     bool humidity:1;
-    bool radio:1;
+    bool radio:1, transponder:1;
+    bool engine:1;
     bool debug:1;
 
     int8_t battery_percent;
@@ -125,6 +106,8 @@ class DeviceListWidget final
       debug = device.IsDumpEnabled();
       radio = basic.settings.has_active_frequency || 
         basic.settings.has_standby_frequency;
+      transponder = basic.settings.has_transponder_code;
+      engine = basic.engine.IsAnyDefined();
       battery_percent = basic.battery_level_available
         ? (int)basic.battery_level
         : -1;
@@ -426,6 +409,13 @@ DeviceListWidget::OnPaintItem(Canvas &canvas, const PixelRect rc,
       buffer.append(_T("Radio"));
     }
 
+    if (flags.transponder) {
+      buffer.append(_T("; XPDR"));
+    }
+
+    if (flags.engine)
+      buffer.append(_T("; Engine"));
+
     if (flags.debug) {
       buffer.append(_T("; "));
       buffer.append(_("Debug"));
@@ -452,9 +442,7 @@ DeviceListWidget::OnPaintItem(Canvas &canvas, const PixelRect rc,
 
     status = buffer;
 #ifdef ANDROID
-  } else if ((config.port_type == DeviceConfig::PortType::RFCOMM ||
-              config.port_type == DeviceConfig::PortType::BLE_HM10 ||
-              config.port_type == DeviceConfig::PortType::RFCOMM_SERVER) &&
+  } else if (config.IsAndroidBluetooth() &&
              bluetooth_helper != nullptr &&
              !bluetooth_helper->IsEnabled(Java::GetEnv())) {
     status = _("Bluetooth is disabled");
