@@ -25,13 +25,11 @@ SimulatorPromptWindow::OnCreate()
   style.TabStop();
 
   fly_bitmap.Load(IDB_LAUNCHER1);
-  fly_bitmap.EnableInterpolation();
   fly_button.Create(*this, rc, style,
                     std::make_unique<BitmapButtonRenderer>(fly_bitmap),
                     [this](){ callback(Result::FLY); });
 
   sim_bitmap.Load(IDB_LAUNCHER2);
-  sim_bitmap.EnableInterpolation();
   sim_button.Create(*this, rc, style,
                     std::make_unique<BitmapButtonRenderer>(sim_bitmap),
                     [this](){ callback(Result::SIMULATOR); });
