@@ -12,8 +12,8 @@
 #include "Form/DataField/Prefix.hpp"
 #include "Form/DataField/Listener.hpp"
 #include "FLARM/FlarmNetRecord.hpp"
-#include "FLARM/FlarmDetails.hpp"
-#include "FLARM/FlarmId.hpp"
+#include "FLARM/Details.hpp"
+#include "FLARM/Id.hpp"
 #include "FLARM/Global.hpp"
 #include "FLARM/TrafficDatabases.hpp"
 #include "util/StaticString.hxx"
