@@ -118,7 +118,10 @@ WaypointInfoWidget::Prepare(ContainerWindow &parent,
                      buffer.buffer(), buffer.capacity()) != nullptr)
     AddReadOnly(_("Location"), nullptr, buffer);
 
-  AddReadOnly(_("Elevation"), nullptr, FormatUserAltitude(waypoint->elevation));
+  if (waypoint->has_elevation)
+    AddReadOnly(_("Elevation"), nullptr, FormatUserAltitude(waypoint->elevation));
+  else
+    AddReadOnly(_("Elevation"), nullptr, _T("?"));
 
   if (basic.time_available && basic.date_time_utc.IsDatePlausible()) {
     const SunEphemeris::Result sun =
@@ -147,7 +150,8 @@ WaypointInfoWidget::Prepare(ContainerWindow &parent,
   }
 
   if (basic.location_available && basic.NavAltitudeAvailable() &&
-      settings.polar.glide_polar_task.IsValid()) {
+      settings.polar.glide_polar_task.IsValid() &&
+      waypoint->has_elevation) {
     const GlideState glide_state(basic.location.DistanceBearing(waypoint->location),
                                  waypoint->elevation + settings.task.safety_height_arrival,
                                  basic.nav_altitude,
@@ -170,7 +174,8 @@ WaypointInfoWidget::Prepare(ContainerWindow &parent,
                                     glide_state));
   }
 
-  if (basic.location_available && basic.NavAltitudeAvailable()) {
+  if (basic.location_available && basic.NavAltitudeAvailable() &&
+      waypoint->has_elevation) {
     const TaskBehaviour &task_behaviour =
       CommonInterface::GetComputerSettings().task;
 
