@@ -6,51 +6,48 @@
 #include "Boundary.hpp"
 #include "Task/Points/TaskPoint.hpp"
 
-ObservationZoneClient::ObservationZoneClient(std::unique_ptr<ObservationZonePoint> _oz_point) noexcept
-  :oz_point(std::move(_oz_point)) {}
-
 ObservationZoneClient::~ObservationZoneClient() noexcept = default;
 
 bool
-ObservationZoneClient::IsInSector(const GeoPoint &location) const
+ObservationZoneClient::IsInSector(const GeoPoint &location) const noexcept
 {
   return oz_point->IsInSector(location);
 }
 
 bool
-ObservationZoneClient::CanStartThroughTop() const
+ObservationZoneClient::CanStartThroughTop() const noexcept
 {
   return oz_point->CanStartThroughTop();
 }
 
 GeoPoint
-ObservationZoneClient::GetRandomPointInSector(const double mag) const
+ObservationZoneClient::GetRandomPointInSector(const double mag) const noexcept
 {
   return oz_point->GetRandomPointInSector(mag);
 }
 
 double
-ObservationZoneClient::ScoreAdjustment() const
+ObservationZoneClient::ScoreAdjustment() const noexcept
 {
   return oz_point->ScoreAdjustment();
 }
 
 OZBoundary
-ObservationZoneClient::GetBoundary() const
+ObservationZoneClient::GetBoundary() const noexcept
 {
   return oz_point->GetBoundary();
 }
 
 bool
 ObservationZoneClient::TransitionConstraint(const GeoPoint &location,
-                                            const GeoPoint &last_location) const
+                                            const GeoPoint &last_location) const noexcept
 {
   return oz_point->TransitionConstraint(location, last_location);
 }
 
 void
 ObservationZoneClient::SetLegs(const TaskPoint *previous,
-                               const TaskPoint *next)
+                               const TaskPoint *next) noexcept
 {
   oz_point->SetLegs(previous != nullptr ? &previous->GetLocation() : nullptr,
                     next != nullptr ? &next->GetLocation() : nullptr);
