@@ -7,6 +7,5 @@ bool
 ObservationZonePoint::Equals(const ObservationZonePoint &other) const noexcept
 {
   return GetShape() == other.GetShape() &&
-    GetReference().Equals(other.GetReference());
+    GetReference() == other.GetReference();
 }
-
