@@ -44,8 +44,19 @@ struct TrafficList {
    * this one.
    */
   constexpr void Complement(const TrafficList &add) noexcept {
-    if (IsEmpty() && !add.IsEmpty())
-      *this = add;
+    if (add.modified.Modified(modified))
+      modified = add.modified;
+
+    if (add.new_traffic.Modified(new_traffic))
+      new_traffic = add.new_traffic;
+
+    if (list.empty() && !add.list.empty()) {
+      /* don't bother merging the two lists, we can simply memcpy()
+         it */
+      list = add.list;
+      return;
+    }
+
     // Add unique traffic from 'add' list
     for (auto &traffic : add.list) {
       if (FindTraffic(traffic.id) == nullptr) {
