@@ -9,7 +9,8 @@
 #include "Math/FastRotation.hpp"
 #include "Units/Units.hpp"
 #include "Units/Descriptor.hpp"
-#include "util/Clamp.hpp"
+
+#include <algorithm> // for std::clamp()
 
 static constexpr double DELTA_V_STEP = 4.0;
 static constexpr double DELTA_V_LIMIT = 16.0;
@@ -330,8 +331,8 @@ GaugeVario::OnPaintBuffer(Canvas &canvas) noexcept
                false, false);
 
   if (Settings().show_gross) {
-    auto vvaldisplay = Clamp(Units::ToUserVSpeed(vval),
-                              -99.9, 99.9);
+    auto vvaldisplay = std::clamp(Units::ToUserVSpeed(vval),
+                                  -99.9, 99.9);
 
     RenderValue(canvas, geometry.gross, gross_di,
                 vvaldisplay,
@@ -419,7 +420,7 @@ GaugeVario::ValueToNeedlePos(double Value) noexcept
 
 
   i = iround(Value * degrees_per_unit);
-  i = Clamp(i, int(gmin), int(gmax));
+  i = std::clamp(i, int(gmin), int(gmax));
   return i;
 }
 
@@ -580,7 +581,7 @@ GaugeVario::RenderSpeedToFly(Canvas &canvas, int x, int y) noexcept
   if ((Calculated().flight.flying)
       && (!Basic().gps.simulator || !Calculated().circling)) {
     v_diff = Calculated().V_stf - Basic().indicated_airspeed;
-    v_diff = Clamp(v_diff, -DELTA_V_LIMIT, DELTA_V_LIMIT); // limit it
+    v_diff = std::clamp(v_diff, -DELTA_V_LIMIT, DELTA_V_LIMIT); // limit it
     v_diff = iround(v_diff/DELTA_V_STEP) * DELTA_V_STEP;
   } else
     v_diff = 0;
