@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "Battery.hpp"
 #include "util/StringAPI.hxx"
@@ -46,7 +26,10 @@ GetInfo() noexcept
 
   char line[256];
 
-  if (DetectKoboModel() == KoboModel::GLO_HD) {
+  switch (DetectKoboModel())
+  {
+  case KoboModel::GLO_HD:
+  case KoboModel::CLARA_HD:
     if (File::ReadString(Path("/sys/class/power_supply/mc13892_bat/status"),
                          line, sizeof(line))) {
       if (StringIsEqual(line,"Not charging\n") ||
@@ -61,7 +44,10 @@ GetInfo() noexcept
       int rem = atoi(line);
       battery.remaining_percent = rem;
     }
-  } else if (DetectKoboModel() == KoboModel::LIBRA2) {
+    break;
+
+  case KoboModel::LIBRA2:
+  case KoboModel::CLARA_2E:
     if (File::ReadString(Path("/sys/class/power_supply/battery/status"),
                          line, sizeof(line))) {
       if (StringIsEqual(line,"Not charging\n") ||
@@ -77,8 +63,9 @@ GetInfo() noexcept
       int rem = atoi(line);
       battery.remaining_percent = rem;
     }
+    break;
 
-  } else {
+  default:
     // code shamelessly copied from OS/SystemLoad.cpp
     if (!File::ReadString(Path("/sys/class/power_supply/mc13892_bat/uevent"),
                           line, sizeof(line)))
@@ -101,6 +88,7 @@ GetInfo() noexcept
         battery.remaining_percent = rem;
       }
     }
+    break;
   }
 
   return info;
