@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "InfoBoxes/Content/Factory.hpp"
 
@@ -42,6 +22,7 @@ Copyright_License {
 #include "InfoBoxes/Content/Weather.hpp"
 #include "InfoBoxes/Content/Airspace.hpp"
 #include "InfoBoxes/Content/Radio.hpp"
+#include "InfoBoxes/Content/Engine.hpp"
 
 #include "util/Macros.hpp"
 #include "Language/Language.hpp"
@@ -1107,6 +1088,38 @@ static constexpr MetaData meta_data[] = {
     UpdateInfoBoxHeartRate,
   },
 
+  // Transponder code
+  {
+    N_("Transponder Code"),
+    N_("XPDR Code"),
+    N_("The currently set Transponder code"),
+    IBFHelper<InfoBoxContentTransponderCode>::Create,
+  },
+
+  // e_EngineTempCHT
+  {
+    N_("Engine CHT"),
+    N_("CHT"),
+    N_("Engine Cylinder Head Temperature"),
+    UpdateInfoBoxContentCHT,
+  },
+
+  // e_EngineTempEGT
+  {
+    N_("Engine EGT"),
+    N_("EGT"),
+    N_("Engine Exhaust Gas Temperature"),
+    UpdateInfoBoxContentEGT,
+  },
+
+  // e_EngineRPM
+  {
+    N_("Engine Revolutions Per Minute"),
+    N_("RPM"),
+    N_("Engine Revolutions Per Minute."),
+    UpdateInfoBoxContentRPM,
+  },
+
 };
 
 static_assert(ARRAY_SIZE(meta_data) == NUM_TYPES,
